.. _documentation:

=============
Documentation
=============

.. htmlonly::

   :Release: |version|
   :Date: |today|

Previous versions: `1.3.0 <http://nipype.readthedocs.io/en/1.3.0/>`_ `1.2.3 <http://nipype.readthedocs.io/en/1.2.3/>`_


.. container:: doc2

  .. admonition:: Michael Notter's Nipype guide

    Be sure to read `Michael's excellent tutorials <https://miykael.github.io/nipype_tutorial/>`_.

  .. admonition:: Interfaces, Workflows and Examples

    .. hlist::
       :columns: 2

       * Workflows

         .. toctree::
            :maxdepth: 1
            :glob:

            interfaces/generated/*workflows*
       * Examples

         .. toctree::
            :maxdepth: 1
            :glob:

            users/examples/*
       * Interfaces

         .. toctree::
            :maxdepth: 1
            :glob:

            interfaces/generated/*algorithms*
            interfaces/generated/*interfaces*

  .. admonition:: Developer Guides

    .. hlist::
       :columns: 2

       * API

         .. toctree::
            :maxdepth: 2

            api/index

       * Developer Guide

         .. toctree::
            :maxdepth: 2

            devel/index

.. include:: links_names.txt
